<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

- [KavaConfigObject][1]
  - [Properties][2]
  - [Examples][3]
  - [tamperAnalyticsHandler][4]
    - [Parameters][5]
    - [Examples][6]
- [KavaEventType][7]
  - [VIEW][8]
  - [IMPRESSION][9]
  - [PLAY_REQUEST][10]
  - [PLAY][11]
  - [RESUME][12]
  - [PAUSE][13]
  - [BUFFER_START][14]
  - [BUFFER_END][15]
  - [REPLAY][16]
  - [SEEK][17]
  - [PLAY_REACHED_25_PERCENT][18]
  - [PLAY_REACHED_50_PERCENT][19]
  - [PLAY_REACHED_75_PERCENT][20]
  - [PLAY_REACHED_100_PERCENT][21]
  - [SOURCE_SELECTED][22]
  - [AUDIO_SELECTED][23]
  - [FLAVOR_SWITCH][24]
  - [CAPTIONS][25]
  - [ERROR][26]
- [Kava][27]
  - [Parameters][28]
  - [destroy][29]
  - [reset][30]
  - [loadMedia][31]
  - [getEventModel][32]
    - [Parameters][33]
    - [Examples][34]
  - [EventType][35]
  - [sendAnalytics][36]
    - [Parameters][37]
    - [Examples][38]
  - [defaultConfig][39]
  - [isValid][40]

## KavaConfigObject

Type: [Object][41]

### Properties

- `serviceUrl` **[string][42]?** The Kaltura API server.
- `requestMethod` **[string][42]?** The http method to be used for sending the beacons, GET or POST, the default is GET.
- `viewEventCountdown` **[number][43]?** The interval in seconds that VIEW event will be sent.
- `resetSessionCountdown` **[number][43]?** The interval in seconds that Kava session will be reset.
- `dvrThreshold` **[number][43]?** Threshold in seconds from the live edge.
- `applicationVersion` **[string][42]?** Used to send the application version from which the user is playing the entry.
- `playbackContext` **[string][42]?** Used to send the id of the category from which the user is playing the entry.
- `tamperAnalyticsHandler` **[Function][44]?** An optional handler to implement. Can be used to manipulate the model data before analytics event sent, or to cancel a certain analytics request.
- `customVar1` **[Object][41]?** Custom objects field.
- `customVar2` **[Object][41]?** Custom objects field.
- `customVar3` **[Object][41]?** Custom objects field.
- `userId` **[string][42]?** custom user id .
- `persistentSessionId` **[string][42]?** UUID for anonymous users.

### Examples

```javascript
// Default config
{
 serviceUrl: '//analytics.kaltura.com/api_v3/index.php',
 requestMethod: 'GET',
 viewEventCountdown: 30,
 resetSessionCountdown: 30,
 dvrThreshold: 120,
 applicationVersion: '',
 playbackContext: ''
}
```

### tamperAnalyticsHandler

#### Parameters

- `model` **[Object][41]** Event model

#### Examples

```javascript
tamperAnalyticsHandler: function (model) {
     // Always add myCustomFlag but don't send the request if the event type equals to 2
     model.myCustomFlag = true;
     if (model.eventType !== 2) {
       return true;
     }
     return false;
   }
```

Returns **[boolean][45]** Should send the request or not.

## KavaEventType

### VIEW

Type: [string][42]

### IMPRESSION

Type: [string][42]

### PLAY_REQUEST

Type: [string][42]

### PLAY

Type: [string][42]

### RESUME

Type: [string][42]

### PAUSE

Type: [string][42]

### BUFFER_START

Type: [string][42]

### BUFFER_END

Type: [string][42]

### REPLAY

Type: [string][42]

### SEEK

Type: [string][42]

### PLAY_REACHED_25_PERCENT

Type: [string][42]

### PLAY_REACHED_50_PERCENT

Type: [string][42]

### PLAY_REACHED_75_PERCENT

Type: [string][42]

### PLAY_REACHED_100_PERCENT

Type: [string][42]

### SOURCE_SELECTED

Type: [string][42]

### AUDIO_SELECTED

Type: [string][42]

### FLAVOR_SWITCH

Type: [string][42]

### CAPTIONS

Type: [string][42]

### ERROR

Type: [string][42]

## Kava

Kaltura Advanced Analytics plugin.

### Parameters

- `name` **[string][42]** The plugin name.
- `player` **Player** The player instance.
- `config` **[KavaConfigObject][46]** The plugin config.

### destroy

Destroys the plugin.

Returns **void**

### reset

Reset the plugin.

Returns **void**

### loadMedia

loadMedia of the plugin.

Returns **void**

### getEventModel

Gets the model object for a certain event.

#### Parameters

- `event` **[string][42]** Event name.

#### Examples

```javascript
const kava = player.plugins.kava;
const viewModel = kava.getEventModel(kava.EventType.VIEW);
kava.sendAnalytics(viewModel);
```

Returns **[Object][41]** Model object.

### EventType

Returns **[KavaEventType][47]** The kava events list.

### sendAnalytics

Sends KAVA analytics event to analytics service.

#### Parameters

- `model` **[Object][41]** Event model.

#### Examples

```javascript
player.plugins.kava.sendAnalytics({...})
.then(() => {
  console.log('kava analytics sent successfully');
})
.catch(e => {
  console.log('kava analytics send failed', e);
});
```

Returns **[Promise][48]** Promise to indicate request succeed or failed.

### defaultConfig

Default config of the plugin.

Type: [Object][41]

### isValid

Returns **[boolean][45]** Whether the plugin is valid in the current environment.

[1]: #kavaconfigobject
[2]: #properties
[3]: #examples
[4]: #tamperanalyticshandler
[5]: #parameters
[6]: #examples-1
[7]: #kavaeventtype
[8]: #view
[9]: #impression
[10]: #play_request
[11]: #play
[12]: #resume
[13]: #pause
[14]: #buffer_start
[15]: #buffer_end
[16]: #replay
[17]: #seek
[18]: #play_reached_25_percent
[19]: #play_reached_50_percent
[20]: #play_reached_75_percent
[21]: #play_reached_100_percent
[22]: #source_selected
[23]: #audio_selected
[24]: #flavor_switch
[25]: #captions
[26]: #error
[27]: #kava
[28]: #parameters-1
[29]: #destroy
[30]: #reset
[31]: #loadmedia
[32]: #geteventmodel
[33]: #parameters-2
[34]: #examples-2
[35]: #eventtype
[36]: #sendanalytics
[37]: #parameters-3
[38]: #examples-3
[39]: #defaultconfig
[40]: #isvalid
[41]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object
[42]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String
[43]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number
[44]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function
[45]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean
[46]: #kavaconfigobject
[47]: #kavaeventtype
[48]: https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Promise
